""" script to check domains against univ toulouse blacklist """

import os
import tarfile

import urllib.request

""" load domain list in memory """

class Blacklist:
  themes = ["adult", "cryptojacking", "phishing"]
  
  @staticmethod
  def url(theme):
    return "ftp://ftp.ut-capitole.fr/pub/reseau/cache/squidguard_contrib/" + theme + ".tar.gz"
  
  def __init__(self):
     self.domains = {}
  
  def ensure_download(self):
    for theme in self.themes:
      filename = theme + ".tar.gz"
      if not os.path.exists("cache/"+theme):
        print("downloading list " + theme + " from " + self.url(theme))
        urllib.request.urlretrieve(self.url(theme), filename)
        with tarfile.open(filename, "r:gz") as tar:
          tar.extractall('cache')
        os.remove(filename)

  def load(self):
    self.ensure_download()
    self.domains = {}
    for theme in self.themes:
      f = open("cache/"+theme+"/domains", 'r')
      for line in f:
          nodes = line.strip().split(".")
          nodes.reverse()
          current = self.domains
          for node in nodes:
              current[node] = current.get(node, {})
              current = current[node]
      f.close()
  def check(self, domain):
    nodes = domain.strip().split(".")
    nodes.reverse()
    current = self.domains
    for node in nodes:
        # subdomain of a blacklisted domain is blacklisted
        if len(current) == 0 and current != self.domains:
            return True
        # not found in tree so not blacklisted
        if node not in current:
            return False
        current = current[node]
    # exact match so domain is blacklisted
    if len(current) == 0:
        return True
    # Parent domain of a blacklisted domain is not blacklisted
    return False